# 默认违禁词库
DEFAULT_BANNED_WORDS = [
    # 1. 绝对性词语
    "最", "最佳", "最具", "最爱", "最赚", "最优", "最优秀", "唯一", "第一", "顶尖", "顶级", "终极", "极致", "最牛逼", "最牛",
    # 2. 夸张表述
    "独一无二", "绝无仅有", "史无前例", "万能", "100 % 有效", "零风险", "特效", "强效", "速效", "彻底解决", "永久", "独家", "王牌", "××之王", "特供", "老字号", "独创", "无可替代", "仅此一次", "MVP", "天花板", "天花顶", "鼻祖",
    # 3. 国家级/国际级词汇
    "国家级（相关单位颁发的除外）", "全球级", "宇宙级", "世界级", "顶级", "顶尖", "尖端", "顶级工艺", "顶级享受", "极品", "极佳（绝佳 / 绝对）", "终极", "极致",
    # 4. 首发/独家词汇
    "首个", "首选", "全球首发", "全国首家", "全网首发", "首款", "独家", "全国销量冠军",
    # 5. 考试培训类
    "包过", "押题命中率百分百", "最权威师资", "一本书学会", "一次通过", "就业保障（无条件承诺）",
    # 6. 投资理财类
    "无风险", "稳赚不赔", "保值", "升值回报", "投资价值", "投资理财零风险", "快速回报", "高收益回报",
    # 7. 迷信色彩词汇
    "冥器", "旺夫", "旺子", "带来好运气", "增强第六感", "逢凶化吉", "避凶", "辟邪", "防小人", "化解小人", "增加事业运", "招财进宝", "健康富贵", "提升运气", "护身", "平衡正负能量", "旺人", "旺财", "旺宅", "镇宅", "消灾", "挡灾", "助吉避凶", "转富招福",
    # 8. 暗示性引导词汇
    "点击有惊喜", "点击获取", "点击试穿", "领取奖品",
    # 9. 刺激抢购心理词汇
    "秒杀", "抢爆", "再不抢就没了", "错过就没机会了", "万人疯抢", "抢疯了",
    # 10. 欺骗性词语
    "点击", "恭喜获奖", "全民免单", "点击有惊喜", "点击获取", "点击试穿", "领取奖品", "非转基因更安全",
    # 11. 化妆品虚假宣传
    "特效", "高效", "全效", "强效", "速效", "美白", "XX天见效", "XX周期见效", "超强", "激活", "全方位全面", "安全", "无毒", "溶脂", "吸脂", "燃烧脂肪", "瘦身", "瘦脸", "瘦腿", "减肥", "祛黑头", "祛痘", "祛闭口延年益寿", '提高',
    "记忆力", "提高肌肤抗刺激", "消除", "清除", "化解死细胞", "去", "祛", "除皱纹平皱", "修复", "断裂弹性", "纤维", "止脱", "采用新型着色机理永不褪色", '迅速修复受紫外线伤害的肌肤', "更新肌肤", "破坏黑色素细胞阻断",
    "黑色素的形成", "丰乳", "丰胸", "使乳房丰满", "预防乳房松弛下垂", "改善", "睡眠", "舒眠",
    # 12. 医疗用语
    "全面调整人体内分泌平衡", "增强或提高免疫力", "助眠", "失眠", "滋阴补阳", "壮阳", "消炎", "可促进新陈代谢", "减少红血丝", "产生优化细胞结构",
    "修复受损肌肤", "治愈", "抗炎", "活血解毒", "抗敏", "脱敏", "减肥", "清热解毒", "清热祛湿", "治疗", "除菌", "杀菌", "抗菌", "灭菌", "防菌",
    "消毒", "排毒", "防敏", "柔敏", "舒敏", "缓敏", "脱敏", "褪敏", "改善敏感肌肤", "改善过敏现象", "降低肌肤敏感度", "镇定", "镇静", "理气",
    "行气", "活血", "生肌肉", "补血", "安神", "养脑", "益气", "通脉", "胃胀蠕动", "利尿", "驱寒解毒", "调节内分泌", "延缓更年期", "补肾", "袪风",
    "生发", "防癌", "抗癌", "祛疤", "降血压", "防止高血压", "治疗", "改善内分泌", "平衡荷尔蒙", "防止卵巢及子宫的功能素乱", "去除体内毒素", "吸附铅汞",
    "除湿", "润燥", "治疗腋臭", "治疗体臭", "治疗阴臭", "美容治疗", "消除斑点", "斑立净", "无斑", "治疗斑秃", "逐层减退多种色斑", "妊娠纹", "毛发新生",
    "毛发再生", "生黑发", "止脱", "生发止脱", "脂溢性脱发", "病变性脱发", "毛囊激活", "酒糟鼻", "伤口愈合清除毒素", "缓解痉李抽搐", "减轻或缓解疾病症状",
    "处方", "药方", "丘疹", "脓疤", "手癣", "甲癣", "体癣", "头癣", "股癣", "脚癣", "脚气", "鹅掌癣", "花癣", "牛皮癣", "传染性湿疹", "伤风感冒", "经痛",
    "肌痛", "头痛", "腹痛", "便秘", "哮喘", "支气管炎", "消化不良", "刀伤", "烧伤", "烫伤", "疮痈", "毛囊炎", "皮肤感染", "皮肤耳部痉挛", "细菌", "真菌",
    "念珠菌", "糠批孢子菌", "厌氧菌", "牙孢菌", "痤疮", "毛囊賽生虫", "雌性激素", "雄性激索", "荷尔蒙", "抗生素", "激素", "药物", "中草药", "中枢神经",
    "细胞再生", "细胞增殖和分化", "免疫力", "患处", "疤痕", "关节痛", "冻疮", "冻伤", "皮肤细胞间的氧气交换", "红肿", "淋巴液", "毛细血毒", "淋巴毒"
]